@@ -14,7 +14,7 @@
 
 from ..magic import Magics, magics_class
 from .auto import AutoMagics
-from .basic import BasicMagics
+from .basic import BasicMagics, AsyncMagics
 from .code import CodeMagics, MacroToEdit
 from .config import ConfigMagics
 from .display import DisplayMagics
