@@ -116,10 +116,9 @@ import traceback
 import types
 import weakref
 from importlib import import_module
+from importlib.util import source_from_cache
 from imp import reload
 
-from IPython.utils import openpy
-
 #------------------------------------------------------------------------------
 # Autoreload functionality
 #------------------------------------------------------------------------------
@@ -195,7 +194,7 @@ class ModuleReloader(object):
             py_filename = filename
         else:
             try:
-                py_filename = openpy.source_from_cache(filename)
+                py_filename = source_from_cache(filename)
             except ValueError:
                 return None, None
 
@@ -270,7 +269,7 @@ def update_function(old, new):
 
 def update_class(old, new):
     """Replace stuff in the __dict__ of a class, and upgrade
-    method code objects"""
+    method code objects, and add new methods, if any"""
     for key in list(old.__dict__.keys()):
         old_obj = getattr(old, key)
         try:
@@ -292,6 +291,13 @@ def update_class(old, new):
         except (AttributeError, TypeError):
             pass # skip non-writable attributes
 
+    for key in list(new.__dict__.keys()):
+        if key not in list(old.__dict__.keys()):
+            try:
+                setattr(old, key, getattr(new, key))
+            except (AttributeError, TypeError):
+                pass # skip non-writable attributes
+
 
 def update_property(old, new):
     """Replace get/set/del functions of a property"""
@@ -332,7 +338,7 @@ class StrongRef(object):
         return self.obj
 
 
-def superreload(module, reload=reload, old_objects={}):
+def superreload(module, reload=reload, old_objects=None):
     """Enhanced version of the builtin reload function.
 
     superreload remembers objects previously in the module, and
@@ -342,6 +348,8 @@ def superreload(module, reload=reload, old_objects={}):
     - clears the module's namespace before reloading
 
     """
+    if old_objects is None:
+        old_objects = {}
 
     # collect old objects in the module
     for name, obj in list(module.__dict__.items()):
