@@ -19,14 +19,15 @@ Limitations:
 # Module imports
 
 # From the standard library
+import builtins as builtin_mod
 import doctest
 import inspect
 import logging
 import os
 import re
 import sys
-import traceback
-import unittest
+from importlib import import_module
+from io import StringIO
 
 from testpath import modified_env
 
@@ -41,18 +42,9 @@ from doctest import (REPORTING_FLAGS, REPORT_ONLY_FIRST_FAILURE,
                      linecache)
 
 # Third-party modules
-import nose.core
 
 from nose.plugins import doctests, Plugin
-from nose.util import anyp, getpackage, test_address, resolve_name, tolist
-
-# Our own imports
-from IPython.utils.py3compat import builtin_mod, PY3, getcwd
-
-if PY3:
-    from io import StringIO
-else:
-    from StringIO import StringIO
+from nose.util import anyp, tolist
 
 #-----------------------------------------------------------------------------
 # Module globals and other constants
@@ -143,7 +135,7 @@ class DocTestFinder(doctest.DocTestFinder):
         # doctests in extension modules.
 
         # Local shorthands
-        from inspect import isroutine, isclass, ismodule
+        from inspect import isroutine, isclass
 
         # Look for tests in a module's contained objects.
         if inspect.ismodule(obj) and self._recurse:
@@ -261,7 +253,7 @@ class DocTestCase(doctests.DocTestCase):
             # Save our current directory and switch out to the one where the
             # test was originally created, in case another doctest did a
             # directory change.  We'll restore this in the finally clause.
-            curdir = getcwd()
+            curdir = os.getcwd()
             #print 'runTest in dir:', self._ori_dir  # dbg
             os.chdir(self._ori_dir)
 
@@ -649,7 +641,7 @@ class ExtensionDoctest(doctests.Doctest):
         modname = os.path.splitext(mod)[0]
         try:
             sys.path.append(bpath)
-            module = __import__(modname)
+            module = import_module(modname)
             tests = list(self.loadTestsFromModule(module))
         finally:
             sys.path.pop()
