@@ -66,62 +66,42 @@ def teardown():
     shutil.rmtree(TMP_TEST_DIR)
     sys.path = old_syspath
 
-
-def test_get_init_1():
-    """See if get_init can find __init__.py in this testdir"""
-    with make_tempfile(join(TMP_TEST_DIR, "__init__.py")):
-        assert mp.get_init(TMP_TEST_DIR)
-
-def test_get_init_2():
-    """See if get_init can find __init__.pyw in this testdir"""
-    with make_tempfile(join(TMP_TEST_DIR, "__init__.pyw")):
-        assert mp.get_init(TMP_TEST_DIR)
-
-def test_get_init_3():
-    """get_init can't find __init__.pyc in this testdir"""
-    with make_tempfile(join(TMP_TEST_DIR, "__init__.pyc")):
-        nt.assert_is_none(mp.get_init(TMP_TEST_DIR))
-
-def test_get_init_4():
-    """get_init can't find __init__ in empty testdir"""
-    nt.assert_is_none(mp.get_init(TMP_TEST_DIR))
-
-
 def test_find_mod_1():
+    """
+    Search for a directory's file path.
+    Expected output: a path to that directory's __init__.py file.
+    """
     modpath = join(TMP_TEST_DIR, "xmod", "__init__.py")
     nt.assert_equal(mp.find_mod("xmod"), modpath)
 
 def test_find_mod_2():
+    """
+    Search for a directory's file path.
+    Expected output: a path to that directory's __init__.py file.
+    TODO: Confirm why this is a duplicate test.
+    """
     modpath = join(TMP_TEST_DIR, "xmod", "__init__.py")
     nt.assert_equal(mp.find_mod("xmod"), modpath)
 
 def test_find_mod_3():
+    """
+    Search for a directory + a filename without its .py extension
+    Expected output: full path with .py extension.
+    """
     modpath = join(TMP_TEST_DIR, "xmod", "sub.py")
     nt.assert_equal(mp.find_mod("xmod.sub"), modpath)
 
 def test_find_mod_4():
+    """
+    Search for a filename without its .py extension
+    Expected output: full path with .py extension
+    """
     modpath = join(TMP_TEST_DIR, "pack.py")
     nt.assert_equal(mp.find_mod("pack"), modpath)
 
 def test_find_mod_5():
-    modpath = join(TMP_TEST_DIR, "packpyc.pyc")
-    nt.assert_equal(mp.find_mod("packpyc"), modpath)
-
-def test_find_module_1():
-    modpath = join(TMP_TEST_DIR, "xmod")
-    nt.assert_equal(mp.find_module("xmod"), modpath)
-
-def test_find_module_2():
-    """Testing sys.path that is empty"""
-    nt.assert_is_none(mp.find_module("xmod", []))
-
-def test_find_module_3():
-    """Testing sys.path that is empty"""
-    nt.assert_is_none(mp.find_module(None, None))
-
-def test_find_module_4():
-    """Testing sys.path that is empty"""
-    nt.assert_is_none(mp.find_module(None))
-
-def test_find_module_5():
-    nt.assert_is_none(mp.find_module("xmod.nopack"))
+    """
+    Search for a filename with a .pyc extension
+    Expected output: TODO: do we exclude or include .pyc files?
+    """
+    nt.assert_equal(mp.find_mod("packpyc"), None)
